==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Couleurs</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Vue graphique</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translatorcomment>--ignored colon--
--file: BitmapExport_fr.ts--
Arrière-plan du dessin :</translatorcomment>
        <translation>Arrière-plan :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Curseur</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Inactive crosshairs:</source>
        <translation>Réticule inactif :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Zéro relative :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Grille</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Métagrille :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Sélection</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">Première couleur pour la sélection :</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Première couleur pour la sélection :</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Utiliser couleur secondaire de sélection</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Couleur secondaire de sélection :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Points de référence :</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Points de référence secondaire :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Bordure de la zone de sélection :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Zone de sélection :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Zone de sélection croisée :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Outils de accrochage</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>L&apos;étiquette d&apos;accrochage :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Outils de information</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mesures et étiquettes :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Outils de dessin</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Formes auxiliaire :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Outils de zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Bordure de la zone de sélection :</translation>
    </message>
    <message>
        <source>Cross hair:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Réticule :</translation>
    </message>
    <message>
        <source>Cross hair Inactive:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Réticule inactif :</translation>
    </message>
    <message>
        <location line="-643"/>
        <source>Crosshairs:</source>
        <translation>Réticule :</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">Réticule inactif :</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Origin:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Origine :</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zéro relative :</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Point de référence :</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: designer_fr.ts--
Métagrille :
&amp;Métagrille :</translatorcomment>
        <translation>Grille :</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Métagrille :</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Boîte zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_fr.ts--</translatorcomment>
        <translation type="obsolete">Sélection :</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Bordure de la zone de sélection :</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zone de sélection :</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zone de sélection croisée :</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Formes auxiliaire :</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fond de l&apos;étiquette d&apos;info :</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Police de l&apos;étiquette d&apos;info :</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Outils de mesure :</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Couleurs</translation>
    </message>
</context>
<context>
    <name>Colors</name>
    <message>
        <source>Colors</source>
        <translation type="obsolete">Couleurs</translation>
    </message>
    <message>
        <source>Graphics View</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Vue graphique</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Vue graphique</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translatorcomment>--ignored colon--
--file: BitmapExport_fr.ts--
Arrière-plan du dessin :</translatorcomment>
        <translation>Arrière-plan :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Curseur</translation>
    </message>
    <message>
        <location line="+54"/>
        <source>Inactive crosshairs:</source>
        <translation>Réticule inactif :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Origine</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Relative zero:</source>
        <translation>Zéro relative :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Grille</translation>
    </message>
    <message>
        <location line="+48"/>
        <source>Meta grid:</source>
        <translation>Métagrille :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Sélection</translation>
    </message>
    <message>
        <source>First selection color:</source>
        <translation type="obsolete">Première couleur pour la sélection :</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Première couleur pour la sélection :</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Utiliser couleur secondaire de sélection</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Couleur secondaire de sélection :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Points de référence :</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Points de référence secondaire :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Bordure de la zone de sélection :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Zone de sélection :</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Zone de sélection croisée :</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Points de départ :</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Points finaux :</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Outils de accrochage</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>L&apos;étiquette d&apos;accrochage :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Outils de information</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Mesures et étiquettes :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Outils de dessin</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Formes auxiliaire :</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Outils de zoom</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Bordure de la zone de sélection :</translation>
    </message>
    <message>
        <source>Cross hair:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Réticule :</translation>
    </message>
    <message>
        <source>Cross hair Inactive:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Réticule inactif :</translation>
    </message>
    <message>
        <location line="-697"/>
        <source>Crosshairs:</source>
        <translation>Réticule :</translation>
    </message>
    <message>
        <source>Inactive Crosshairs:</source>
        <translation type="obsolete">Réticule inactif :</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Origin:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Origine :</translation>
    </message>
    <message>
        <source>Relative Zero:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zéro relative :</translation>
    </message>
    <message>
        <source>Reference Point:</source>
        <translation type="obsolete">Point de référence :</translation>
    </message>
    <message>
        <location line="+81"/>
        <source>Grid:</source>
        <translatorcomment>--ignored colon--
--file: designer_fr.ts--
Métagrille :
&amp;Métagrille :</translatorcomment>
        <translation>Grille :</translation>
    </message>
    <message>
        <source>Meta Grid:</source>
        <translation type="obsolete">Métagrille :</translation>
    </message>
    <message>
        <source>Zoom Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Boîte zoom:</translation>
    </message>
    <message>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: qt_fr.ts--</translatorcomment>
        <translation type="obsolete">Sélection :</translation>
    </message>
    <message>
        <source>Selection Box Border:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Bordure de la zone de sélection :</translation>
    </message>
    <message>
        <source>Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zone de sélection :</translation>
    </message>
    <message>
        <source>Cross Selection Box:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Zone de sélection croisée :</translation>
    </message>
    <message>
        <source>Auxiliary Shapes:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Formes auxiliaire :</translation>
    </message>
    <message>
        <source>Info Label Background:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Fond de l&apos;étiquette d&apos;info :</translation>
    </message>
    <message>
        <source>Info Label Font:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Police de l&apos;étiquette d&apos;info :</translation>
    </message>
    <message>
        <source>Measurement Tools:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Outils de mesure :</translation>
    </message>
</context>
</TS>
